@@ -106,8 +106,8 @@ class UploadTaskAchievementEvent(ContractEvent):
 
     TYPE = 'upload_task_achieve'
 
-    report: str
     model: str
+    report: str = None
 
     @classmethod
     def contract_to_event(cls, contract: dict) -> None:
@@ -300,7 +300,7 @@ class TaskMessageContractor(Contractor):
     def upload_task_achivement(self,
                                aggregator: str,
                                model_file: str,
-                               report_file: str = None):
+                               report_file: str = ''):
         """Upload achivement materials after a task is complete.
 
         :args
