@@ -8,8 +8,8 @@ sys.path.insert(0, PYTHONPATH)
 
 if True:
     from alphafed import logger
-    from alphafed.examples.hetero_nn.psi.demos import (DATA_OWNER_3_ID,
-                                                       get_ids, get_task_id)
+    from alphafed.examples.hetero_nn import DATA_OWNER_3_ID
+    from alphafed.examples.hetero_nn.psi.demos import get_ids, get_task_id
     from alphafed.hetero_nn.psi import RSAPSICollaboratorScheduler
 
 
