@@ -904,7 +904,11 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
             partner_W = partner_linear.weight
             proj_grad = self._feature_fusion_map[feature_key].grad
             cipher_grad = cipher_acc.broadcast_(partner_W.shape).add_(partner_W.tolist())
-            cipher_grad.mm_(proj_grad.T).transpose_()
+            try:
+                cipher_grad.mm_(proj_grad.T).transpose_()
+            except ValueError:
+                logger.error(f'{proj_grad.T=}')
+                raise
             self.data_channel.send_stream(source=self.id,
                                           target=_partner,
                                           data_stream=cipher_grad.serialize(),
